@@ -3,12 +3,12 @@ use warnings;
 
 package Task::MapMetro::Maps;
 
-our $VERSION = '0.1301'; # VERSION
+# ABSTRACT: Map::Metro maps in a bundle
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1302'; # VERSION
 
 1;
 
-# ABSTRACT: Map::Metro maps in a bundle
-
 __END__
 
 =pod
@@ -19,19 +19,28 @@ __END__
 
 Task::MapMetro::Maps - Map::Metro maps in a bundle
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-Task-MapMetro-Maps"><img src="https://api.travis-ci.org/Csson/p5-Task-MapMetro-Maps.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Task-MapMetro-Maps-0.1302"><img src="https://badgedepot.code301.com/badge/kwalitee/Task-MapMetro-Maps/0.1302" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Task-MapMetro-Maps%200.1302"><img src="https://badgedepot.code301.com/badge/cpantesters/Task-MapMetro-Maps/0.1302" alt="CPAN Testers result" /></a>
+</p>
+
+=end html
+
 =head1 VERSION
 
-version 0.1301
-
-=head1 SYNOPSIS
-
-    $ cpanm Task::MapMetro::Maps
+Version 0.1302, released 2016-05-14.
 
 =head1 TASK CONTENTS
 
 =head2 Map::Metro
 
-=head3 L<Map::Metro> 0.2206
+=head3 L<Map::Metro> 0.2404
 
 =head2 Available maps
 
@@ -43,10 +52,6 @@ version 0.1301
 
 =head3 L<Map::Metro::Plugin::Map::Berlin>
 
-=head3 L<Map::Metro::Plugin::Map::Bilbao>
-
-=head3 L<Map::Metro::Plugin::Map::Brescia>
-
 =head3 L<Map::Metro::Plugin::Map::Brussels>
 
 =head3 L<Map::Metro::Plugin::Map::Budapest>
@@ -67,6 +72,10 @@ version 0.1301
 
 =head3 L<Map::Metro::Plugin::Map::Stockholm>
 
+=head1 SYNOPSIS
+
+    $ cpanm Task::MapMetro::Maps
+
 =head1 SEE ALSO
 
 L<Map::Metro>
@@ -86,13 +95,21 @@ Copyright 2015 - Erik Carlsson
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 SOURCE
+
+L<https://github.com/Csson/p5-Task-MapMetro-Maps>
+
+=head1 HOMEPAGE
+
+L<https://metacpan.org/release/Task-MapMetro-Maps>
+
 =head1 AUTHOR
 
 Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
